@@ -51,6 +51,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk
@@ -75,15 +77,15 @@ class SecureBucket(
         block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
         bucket_key_enabled: typing.Optional[builtins.bool] = None,
         bucket_name: typing.Optional[builtins.str] = None,
-        cors: typing.Optional[typing.Sequence[aws_cdk.aws_s3.CorsRule]] = None,
+        cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
         encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
         enforce_ssl: typing.Optional[builtins.bool] = None,
         event_bridge_enabled: typing.Optional[builtins.bool] = None,
-        intelligent_tiering_configurations: typing.Optional[typing.Sequence[aws_cdk.aws_s3.IntelligentTieringConfiguration]] = None,
-        inventories: typing.Optional[typing.Sequence[aws_cdk.aws_s3.Inventory]] = None,
-        lifecycle_rules: typing.Optional[typing.Sequence[aws_cdk.aws_s3.LifecycleRule]] = None,
-        metrics: typing.Optional[typing.Sequence[aws_cdk.aws_s3.BucketMetrics]] = None,
+        intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
+        inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
+        lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
+        metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
         notifications_handler_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
@@ -94,8 +96,8 @@ class SecureBucket(
         versioned: typing.Optional[builtins.bool] = None,
         website_error_document: typing.Optional[builtins.str] = None,
         website_index_document: typing.Optional[builtins.str] = None,
-        website_redirect: typing.Optional[aws_cdk.aws_s3.RedirectTarget] = None,
-        website_routing_rules: typing.Optional[typing.Sequence[aws_cdk.aws_s3.RoutingRule]] = None,
+        website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
+        website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -127,6 +129,42 @@ class SecureBucket(
         :param website_redirect: Specifies the redirect behavior of all requests to a website endpoint of a bucket. If you specify this property, you can't specify "websiteIndexDocument", "websiteErrorDocument" nor , "websiteRoutingRules". Default: - No redirection.
         :param website_routing_rules: Rules that define when a redirect is applied and the redirect behavior. Default: - No redirection rules.
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+                auto_delete_objects: typing.Optional[builtins.bool] = None,
+                block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
+                bucket_key_enabled: typing.Optional[builtins.bool] = None,
+                bucket_name: typing.Optional[builtins.str] = None,
+                cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
+                encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                enforce_ssl: typing.Optional[builtins.bool] = None,
+                event_bridge_enabled: typing.Optional[builtins.bool] = None,
+                intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
+                inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
+                lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
+                metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
+                notifications_handler_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
+                public_read_access: typing.Optional[builtins.bool] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                server_access_logs_prefix: typing.Optional[builtins.str] = None,
+                transfer_acceleration: typing.Optional[builtins.bool] = None,
+                versioned: typing.Optional[builtins.bool] = None,
+                website_error_document: typing.Optional[builtins.str] = None,
+                website_index_document: typing.Optional[builtins.str] = None,
+                website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
+                website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = aws_cdk.aws_s3.BucketProps(
             access_control=access_control,
             auto_delete_objects=auto_delete_objects,
@@ -158,13 +196,18 @@ class SecureBucket(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="bucket")
     def bucket(self) -> aws_cdk.aws_s3.Bucket:
         return typing.cast(aws_cdk.aws_s3.Bucket, jsii.get(self, "bucket"))
 
     @bucket.setter
     def bucket(self, value: aws_cdk.aws_s3.Bucket) -> None:
+        if __debug__:
+            def stub(value: aws_cdk.aws_s3.Bucket) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "bucket", value)
 
 
